# Third-Party Library Selection

## Selection Criteria

- **IMPORTANT** Long-lasting community, lots of docs/discussion/examples (so there will be lots of pretraining data to help LLM coding models)
- Well-designed API: Intuitive, composable, type-safe (for TypeScript)
- Plus any other criteria from the user


## Process
- Understand requirements first. see `SOUNDING_BOARD_MODE.md`. Ask questions if you need to clarify
- Read relevant code/docs to understand the relevant technology stack & architecture for this project
- Search the web. Evaluate options, tradeoffs
- Make a recommendation
- Discuss with user
- Write a doc describing the chosen library, as per `WRITE_DEEP_DIVE_DOC.md`